@@ -1,6 +1,6 @@
 /* PASSDSS-3DES-1 SASL plugin
  * Ken Murchison
- * $Id: passdss.c,v 1.3 2004/11/27 16:17:43 ken3 Exp $
+ * $Id: passdss.c,v 1.4 2006/04/24 19:21:44 mel Exp $
  */
 /* 
  * Copyright (c) 1998-2004 Carnegie Mellon University.  All rights reserved.
@@ -67,6 +67,9 @@
 /* for digest and cipher support */
 #include <openssl/evp.h>
 #include <openssl/hmac.h>
+#include <openssl/md5.h>
+#include <openssl/sha.h>
+#include <openssl/dsa.h>
 
 #include <sasl.h>
 #define MD5_H  /* suppress internal MD5 */
@@ -80,7 +83,7 @@
 
 /*****************************  Common Section  *****************************/
 
-static const char plugin_id[] = "$Id: passdss.c,v 1.3 2004/11/27 16:17:43 ken3 Exp $";
+static const char plugin_id[] = "$Id: passdss.c,v 1.4 2006/04/24 19:21:44 mel Exp $";
 
 const char g[] = "2";
 const char N[] = "FFFFFFFFFFFFFFFFC90FDAA22168C234C4C6628B80DC1CD129024E088A67CC74020BBEA63B139B22514A08798E3404DDEF9519B3CD3A431B302B0A6DF25F14374FE1356D6D51C245E485B576625E7EC6F44C42E9A637ED6B0BFF5CB6F406B7EDEE386BFB5A899FA5AE9F24117C4B1FE649286651ECE65381FFFFFFFFFFFFFFFF";
