@@ -1,7 +1,7 @@
 /* testsuite.c -- Stress the library a little
  * Rob Siemborski
  * Tim Martin
- * $Id: testsuite.c,v 1.40 2004/10/26 11:39:41 mel Exp $
+ * $Id: testsuite.c,v 1.46 2006/04/25 14:39:04 mel Exp $
  */
 /* 
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
@@ -97,11 +97,12 @@ char myhostname[1024+1];
 #define REALLY_LONG_LENGTH  32000
 #define REALLY_LONG_BACKOFF  2000
 
-const char *username = "shadow";
+const char *username = "murch";
 const char *nonexistant_username = "ABCDEFGHIJ";
-const char *authname = "shadow";
-const char *proxyasname = "shadowproxy";
+const char *authname = "murch";
+const char *proxyasname = "murchproxy";
 const char *password = "1234";
+sasl_secret_t * g_secret = NULL;
 const char *cu_plugin = "INTERNAL";
 char other_result[1024];
 
@@ -170,8 +171,6 @@ int test_getrealm(void *context __attribute__((unused)), int id,
     return SASL_OK;
 }
 
-/* yeah, yeah, this leaks memory, but we don't really care in
- * the testsuite */
 int test_getsecret(sasl_conn_t *conn __attribute__((unused)),
 		   void *context __attribute__((unused)), int id,
 		   sasl_secret_t **psecret) 
@@ -179,9 +178,7 @@ int test_getsecret(sasl_conn_t *conn __attribute__((unused)),
     if(id != SASL_CB_PASS) fatal("test_getsecret not looking for pass");
     if(!psecret) return SASL_BADPARAM;
 
-    *psecret = malloc(sizeof(sasl_secret_t) + strlen(password));
-    (*psecret)->len = (unsigned) strlen(password);
-    strcpy((*psecret)->data, password);
+    *psecret = g_secret;
 
     return SASL_OK;
 }
@@ -956,9 +953,9 @@ void test_64(void)
     
     if (sasl_encode64(orig, sizeof(orig), enc, sizeof(enc), &encsize)!=SASL_OK) 
 	fatal("encode64 failed when we didn't expect it to");
-    
+
     if (sasl_decode64(enc, encsize, enc, 8192, &encsize)!=SASL_OK)
-	fatal("decode failed when didn't expect");
+	fatal("decode64 failed when we didn't expect it to");
     
     if (encsize != sizeof(orig)) fatal("Now has different size");
     
@@ -978,7 +975,48 @@ void test_64(void)
 
     if (sasl_encode64(orig, sizeof(orig), enc, sizeof(enc), NULL)!=SASL_OK)
 	fatal("Didn't allow null return size");
-    
+
+    /* New tests in 2.1.22 */
+    for (lup=0;lup<(int) sizeof(orig);lup++) {
+	enc[lup] = 'A';
+    }
+
+    if (sasl_decode64(enc, 3, orig, 8192, &encsize) != SASL_CONTINUE)
+	fatal("decode64 succeded on a 3 byte buffer when it shouldn't have");
+
+    enc[3] = '\r';
+    enc[4] = '\n';
+
+    if (sasl_decode64(enc, 4, orig, 8192, &encsize) == SASL_OK)
+	fatal("decode64 succeded on a 4 byte buffer with a bare CR");
+
+    if (sasl_decode64(enc, 5, orig, 8192, &encsize) == SASL_OK)
+	fatal("decode64 succeded on a 5 byte buffer with CRLF");
+
+    enc[2] = '=';
+    enc[3] = '=';
+    enc[4] = '=';
+
+    if (sasl_decode64(enc, 4, orig, 8192, &encsize) != SASL_OK)
+	fatal("decode64 failed on a 4 byte buffer with a terminating =");
+
+    if (sasl_decode64(enc, 5, orig, 8192, &encsize) != SASL_BADPROT)
+	fatal("decode64 did not return SASL_CONTINUE on a 5 byte buffer with a terminating =");
+
+    /* Test for invalid character after the terminating '=' */
+    enc[3] = '*';
+
+    if (sasl_decode64(enc, 4, orig, 8192, &encsize) == SASL_OK)
+	fatal("decode64 failed on a 4 byte buffer with invalid character a terminating =");
+
+    /* Test for '=' in the middle of an encoded string */
+    enc[3] = 'B';
+
+    if (sasl_decode64(enc, 4, orig, 8192, &encsize) == SASL_OK)
+	fatal("decode64 succeed on a 4 byte buffer with a data after a terminating =");
+
+    if (sasl_decode64(enc, 0, orig, 8192, &encsize) != SASL_OK)
+	fatal("decode64 should have succeeded on an empty buffer");
 }
 
 /* This isn't complete, but then, what in the testsuite is? */
@@ -1001,7 +1039,8 @@ void test_props(void)
 	"a",
 	"b",
 	"c",
-	"defghijklmnop"
+	"defghijklmnop",
+	NULL
     };
 
     const char *short_requests[] = {
@@ -2306,7 +2345,6 @@ void testseclayer(char *mech, void *rock __attribute__((unused)))
     sasl_encode(NULL, txstring, (unsigned) strlen(txstring), &out, &outlen);
     sasl_encode(cconn, NULL, (unsigned) strlen(txstring), &out, &outlen);
     sasl_encode(cconn, txstring, 0, &out, &outlen);
-    sasl_encode(cconn, txstring, (unsigned)-1, &out, &outlen);
     sasl_encode(cconn, txstring, (unsigned) strlen(txstring), NULL, &outlen);
     sasl_encode(cconn, txstring, (unsigned) strlen(txstring), &out, NULL);
     
@@ -2947,6 +2985,10 @@ int main(int argc, char **argv)
 	    break;
     }
 
+    g_secret = malloc(sizeof(sasl_secret_t) + strlen(password));
+    g_secret->len = (unsigned) strlen(password);
+    strcpy(g_secret->data, password);
+
     if(random_tests < 0) random_tests = 25;
 
     notes();
@@ -3080,5 +3122,7 @@ int main(int argc, char **argv)
 
     printf("All tests seemed to go ok (i.e. we didn't crash)\n");
 
+    free(g_secret);
+
     exit(0);
 }
